import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public class Configuration {
   private static final String CONFIG_FILE_NAME = "nscp/config.properties";
   private final Properties properties = new Properties();
   private final File configFile = new File("nscp/config.properties");

   public Configuration() {
      if (!this.configFile.exists()) {
         this.saveDefaultConfig();
      }

      this.loadConfig();
   }

   private void loadConfig() {
      try {
         FileInputStream var1 = new FileInputStream(this.configFile);

         try {
            this.properties.load(var1);
         } catch (Throwable var5) {
            try {
               var1.close();
            } catch (Throwable var4) {
               var5.addSuppressed(var4);
            }

            throw var5;
         }

         var1.close();
      } catch (IOException var6) {
         var6.printStackTrace();
      }

   }

   private void saveConfig() {
      try {
         FileOutputStream var1 = new FileOutputStream(this.configFile);

         try {
            this.properties.store(var1, (String)null);
         } catch (Throwable var5) {
            try {
               var1.close();
            } catch (Throwable var4) {
               var5.addSuppressed(var4);
            }

            throw var5;
         }

         var1.close();
      } catch (IOException var6) {
         var6.printStackTrace();
      }

   }

   private void saveDefaultConfig() {
      this.configFile.getParentFile().mkdirs();

      try {
         InputStream var1 = this.getClass().getResourceAsStream("/nscp/config.properties");

         try {
            if (var1 != null) {
               this.properties.load(var1);
               this.saveConfig();
            } else {
               System.err.println("[ERROR] Default configuration file not found in JAR!");
            }
         } catch (Throwable var5) {
            if (var1 != null) {
               try {
                  var1.close();
               } catch (Throwable var4) {
                  var5.addSuppressed(var4);
               }
            }

            throw var5;
         }

         if (var1 != null) {
            var1.close();
         }
      } catch (IOException var6) {
         var6.printStackTrace();
      }

   }

   public String getString(String var1, String var2) {
      return this.properties.getProperty(var1, var2);
   }

   public boolean getBoolean(String var1, boolean var2) {
      String var3 = String.valueOf(var2);
      return Boolean.parseBoolean(this.properties.getProperty(var1, var3));
   }

   public void setString(String var1, String var2) {
      this.properties.setProperty(var1, var2);
      this.saveConfig();
   }
}
